# loguru_configurable - version 0.2.0 #

[![pypi](https://img.shields.io/pypi/v/loguru_configurable.svg)](https://pypi.python.org/pypi/loguru_configurable)
[![versions](https://img.shields.io/pypi/pyversions/loguru_configurable.svg)](https://github.com/StockwatchDev/loguru_configurable)
<!-- [![Build Status](https://github.com/StockwatchDev/application_settings/actions/workflows/merge_checks.yml/badge.svg?branch=develop)](https://github.com/StockwatchDev/application_settings/actions) -->
<!-- [![codecov](https://codecov.io/gh/StockwatchDev/application_settings/branch/develop/graph/badge.svg)](https://app.codecov.io/gh/StockwatchDev/application_settings) -->
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/PyCQA/pylint)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

Wrapper that adds an [application_settings](https://github.com/StockwatchDev/application_settings) ConfigSection to
[loguru](https://github.com/Delgan/loguru), a library which aims to bring enjoyable logging in Python.

Also relies on [loguru-config](https://github.com/erezinman/loguru-config) and
[loguru-logging-intercept](https://github.com/MatthewScholefield/loguru-logging-intercept).

This project is licensed under the terms of the MIT license.
